@@ -2,4 +2,7 @@
 # from additional_functions import *
 # from PLSQL_geodata_importer import PLSQL_geodata_importer
 from importlib.metadata import version
-__version__ = version("nurtelecom_gras_library")
\ No newline at end of file
+__version__ = version("nurtelecom_gras_library")
+
+from additional_functions import *
+from PLSQL_data_importer import PLSQL_data_importer
\ No newline at end of file
